
# Slot: minimum_value


for slots with ranges of type number, the value must be equal to or higher than this

URI: [linkml:minimum_value](https://w3id.org/linkml/minimum_value)


## Domain and Range

[SlotDefinition](SlotDefinition.md) &#8594;  <sub>0..1</sub> [Integer](types/Integer.md)

## Parents


## Children


## Used by

 * [SlotDefinition](SlotDefinition.md)
